products Package
================

:mod:`products` Package
-----------------------

.. automodule:: pyiem.nws.products
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`cli` Module
-----------------

.. automodule:: pyiem.nws.products.cli
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`hwo` Module
-----------------

.. automodule:: pyiem.nws.products.hwo
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`lsr` Module
-----------------

.. automodule:: pyiem.nws.products.lsr
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`mcd` Module
-----------------

.. automodule:: pyiem.nws.products.mcd
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`nhc` Module
-----------------

.. automodule:: pyiem.nws.products.nhc
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`pirep` Module
-------------------

.. automodule:: pyiem.nws.products.pirep
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`sigmet` Module
--------------------

.. automodule:: pyiem.nws.products.sigmet
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`spacewx` Module
---------------------

.. automodule:: pyiem.nws.products.spacewx
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`vtec` Module
------------------

.. automodule:: pyiem.nws.products.vtec
    :members:
    :undoc-members:
    :show-inheritance:

